@@ -1,6 +1,7 @@
 package Bot::ChatBots::Weak;
 use strict;
-{ our $VERSION = '0.004'; }
+use warnings;
+{ our $VERSION = '0.006'; }
 
 use Scalar::Util qw< weaken >;
 
@@ -34,7 +35,7 @@ sub set {
       weaken($self->{$key}) if ref $value;
    }
    return $self;
-}
+} ## end sub set
 
 sub TO_JSON { return undef }
 
